@@ -37,7 +37,7 @@
 /* on the simplex method is used.                                     */
 /*--------------------------------------------------------------------*/
 
-static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 4.10";
+static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 4.11";
 /* version string */
 
 static int format = 4;
@@ -83,6 +83,9 @@ static int method = 0;
    1 - interior point
    2 - branch-and-bound */
 
+static int primal = 0;
+/* if this flag is set, use lpx_primal rather than lpx_simplex */
+
 static int intopt = 0;
 /* if this flag is set, use lpx_intopt rather than lpx_integer */
 
@@ -127,7 +130,7 @@ static char *out_glp = NULL;
 /* name of output text file, to which the problem should be written in
    GNU LP format; NULL means no GNU LP output */
 
-static char *hardcopy = NULL;
+static char *log_file = NULL;
 /* name of output text file, to which a hardcopy of all screen output
    should be written; NULL means no hardcopying */
 
@@ -189,10 +192,12 @@ static void display_help(char *my_name)
 {     print("Usage: %s [options...] filename", my_name);
       print("");
       print("General options:");
+#if 0
       print("   --glp             read LP/MIP model in GNU LP format");
-      print("   --mps             read LP/MIP problem in fixed MPS form"
+#endif
+      print("   --mps             read LP/MIP problem in Fixed MPS form"
          "at");
-      print("   --freemps         read LP/MIP problem in free MPS forma"
+      print("   --freemps         read LP/MIP problem in Free MPS forma"
          "t (default)");
       print("   --cpxlp           read LP/MIP problem in CPLEX LP forma"
          "t");
@@ -239,19 +244,21 @@ static void display_help(char *my_name)
       print("   --orig            try using original names of rows and "
          "columns");
       print("                     (default for --mps)");
+#if 0
       print("   --wglp filename   write problem to filename in GNU LP f"
          "ormat");
-      print("   --wmps filename   write problem to filename in fixed MP"
+#endif
+      print("   --wmps filename   write problem to filename in Fixed MP"
          "S format");
       print("   --wfreemps filename");
-      print("                     write problem to filename in free MPS"
+      print("                     write problem to filename in Free MPS"
          " format");
       print("   --wcpxlp filename write problem to filename in CPLEX LP"
          " format");
       print("   --wtxt filename   write problem to filename in plain te"
          "xt format");
-      print("   --hcpy filename   write hardcopy of screen output to fi"
-         "lename");
+      print("   --log filename    write copy of screen output to filena"
+         "me");
       print("   -h, --help        display this help information and exi"
          "t");
       print("   -v, --version     display program version and exit");
@@ -507,17 +514,17 @@ static void parse_cmdline(int argc, char *argv[])
             }
             out_txt = argv[k];
          }
-         else if (p("--hcpy"))
+         else if (p("--log"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
-            {  print("No screen hardcopy file specified");
+            {  print("No log file specified");
                exit(EXIT_FAILURE);
             }
-            if (hardcopy != NULL)
-            {  print("Only one screen hardcopy file allowed");
+            if (log_file != NULL)
+            {  print("Only one log file allowed");
                exit(EXIT_FAILURE);
             }
-            hardcopy = argv[k];
+            log_file = argv[k];
          }
          else if (p("--wglp"))
          {  k++;
@@ -535,6 +542,8 @@ static void parse_cmdline(int argc, char *argv[])
             display_help(argv[0]);
          else if (p("-v") || p("--version"))
             display_version();
+         else if (p("--primal"))
+            primal = 1;
          else if (p("--std"))
             basis = 0, presol = 0;
          else if (p("--adv"))
@@ -650,11 +659,11 @@ int main(int argc, char *argv[])
       if (out_cpxlp != NULL) remove(out_cpxlp);
       if (out_txt != NULL) remove(out_txt);
       if (out_glp != NULL) remove(out_glp);
-      if (hardcopy != NULL) remove(hardcopy);
+      if (log_file != NULL) remove(log_file);
       /* open screen hardcopy file, if necessary */
-      if (hardcopy != NULL)
-      {  if (lib_open_hardcopy(hardcopy))
-         {  print("Unable to create screen hardcopy file");
+      if (log_file != NULL)
+      {  if (lib_open_hardcopy(log_file))
+         {  print("Unable to create log file");
             exit(EXIT_FAILURE);
          }
       }
@@ -835,7 +844,7 @@ nobs:    ;
       switch (method)
       {  case 0:
             if (nomip || lpx_get_class(lp) == LPX_LP)
-            {  ret = lpx_simplex(lp);
+            {  ret = (!primal ? lpx_simplex(lp) : lpx_primal(lp));
                if (presol && ret != LPX_E_OK && (out_bas != NULL ||
                   out_sol != NULL))
                   print("If you need actual output for non-optimal solu"
@@ -844,7 +853,7 @@ nobs:    ;
             else
             {  method = 2;
                if (!intopt)
-               {  lpx_simplex(lp);
+               {  (!primal ? lpx_simplex(lp) : lpx_primal(lp));
                   lpx_integer(lp);
                }
                else
